# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class Html5ExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'default_regular_font': 'str',
        'gradient_style': 'str',
        'font_fallback_rules': 'list[FontFallbackRule]',
        'font_subst_rules': 'list[FontSubstRule]',
        'format': 'str',
        'animate_transitions': 'bool',
        'animate_shapes': 'bool',
        'embed_images': 'bool',
        'notes_comments_layouting': 'NotesCommentsLayoutingOptions',
        'templates_path': 'str'
    }

    attribute_map = {
        'default_regular_font': 'defaultRegularFont',
        'gradient_style': 'gradientStyle',
        'font_fallback_rules': 'fontFallbackRules',
        'font_subst_rules': 'fontSubstRules',
        'format': 'format',
        'animate_transitions': 'animateTransitions',
        'animate_shapes': 'animateShapes',
        'embed_images': 'embedImages',
        'notes_comments_layouting': 'notesCommentsLayouting',
        'templates_path': 'templatesPath'
    }

    type_determiners = {
        'format': 'html5',
    }

    def __init__(self, default_regular_font=None, gradient_style=None, font_fallback_rules=None, font_subst_rules=None, format='html5', animate_transitions=None, animate_shapes=None, embed_images=None, notes_comments_layouting=None, templates_path=None):  # noqa: E501
        """Html5ExportOptions - a model defined in Swagger"""  # noqa: E501
        super(Html5ExportOptions, self).__init__(default_regular_font, gradient_style, font_fallback_rules, font_subst_rules, format)

        self._animate_transitions = None
        self._animate_shapes = None
        self._embed_images = None
        self._notes_comments_layouting = None
        self._templates_path = None
        self.format = 'html5'

        if animate_transitions is not None:
            self.animate_transitions = animate_transitions
        if animate_shapes is not None:
            self.animate_shapes = animate_shapes
        if embed_images is not None:
            self.embed_images = embed_images
        if notes_comments_layouting is not None:
            self.notes_comments_layouting = notes_comments_layouting
        if templates_path is not None:
            self.templates_path = templates_path

    @property
    def animate_transitions(self):
        """Gets the animate_transitions of this Html5ExportOptions.  # noqa: E501

        Gets or sets transitions animation option.  # noqa: E501

        :return: The animate_transitions of this Html5ExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._animate_transitions

    @animate_transitions.setter
    def animate_transitions(self, animate_transitions):
        """Sets the animate_transitions of this Html5ExportOptions.

        Gets or sets transitions animation option.  # noqa: E501

        :param animate_transitions: The animate_transitions of this Html5ExportOptions.  # noqa: E501
        :type: bool
        """
        self._animate_transitions = animate_transitions

    @property
    def animate_shapes(self):
        """Gets the animate_shapes of this Html5ExportOptions.  # noqa: E501

        Gets or sets shapes animation option.  # noqa: E501

        :return: The animate_shapes of this Html5ExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._animate_shapes

    @animate_shapes.setter
    def animate_shapes(self, animate_shapes):
        """Sets the animate_shapes of this Html5ExportOptions.

        Gets or sets shapes animation option.  # noqa: E501

        :param animate_shapes: The animate_shapes of this Html5ExportOptions.  # noqa: E501
        :type: bool
        """
        self._animate_shapes = animate_shapes

    @property
    def embed_images(self):
        """Gets the embed_images of this Html5ExportOptions.  # noqa: E501

        Gets or sets embed images option.  # noqa: E501

        :return: The embed_images of this Html5ExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._embed_images

    @embed_images.setter
    def embed_images(self, embed_images):
        """Sets the embed_images of this Html5ExportOptions.

        Gets or sets embed images option.  # noqa: E501

        :param embed_images: The embed_images of this Html5ExportOptions.  # noqa: E501
        :type: bool
        """
        self._embed_images = embed_images

    @property
    def notes_comments_layouting(self):
        """Gets the notes_comments_layouting of this Html5ExportOptions.  # noqa: E501

        Slides layouting options  # noqa: E501

        :return: The notes_comments_layouting of this Html5ExportOptions.  # noqa: E501
        :rtype: NotesCommentsLayoutingOptions
        """
        return self._notes_comments_layouting

    @notes_comments_layouting.setter
    def notes_comments_layouting(self, notes_comments_layouting):
        """Sets the notes_comments_layouting of this Html5ExportOptions.

        Slides layouting options  # noqa: E501

        :param notes_comments_layouting: The notes_comments_layouting of this Html5ExportOptions.  # noqa: E501
        :type: NotesCommentsLayoutingOptions
        """
        self._notes_comments_layouting = notes_comments_layouting

    @property
    def templates_path(self):
        """Gets the templates_path of this Html5ExportOptions.  # noqa: E501

        Path to custom templates  # noqa: E501

        :return: The templates_path of this Html5ExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._templates_path

    @templates_path.setter
    def templates_path(self, templates_path):
        """Sets the templates_path of this Html5ExportOptions.

        Path to custom templates  # noqa: E501

        :param templates_path: The templates_path of this Html5ExportOptions.  # noqa: E501
        :type: str
        """
        self._templates_path = templates_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Html5ExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import io
import json
import ssl
import sys
import certifi
import logging
import re

# python 2 and python 3 compatibility library
from six import PY3
from six.moves.urllib.parse import urlencode

try:
    import urllib3
except ImportError:
    raise ImportError('Swagger python client requires urllib3.')

logger = logging.getLogger(__name__)

class RESTResponse(io.IOBase):

    def __init__(self, resp):
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """
        Returns a dictionary of the response headers.
        """
        return self.urllib3_response.getheaders()

    def getheader(self, name, default=None):
        """
        Returns a given response header.
        """
        return self.urllib3_response.getheader(name, default)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=4):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680
        # maxsize is the number of requests to host that are allowed in parallel
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html

        if configuration.debug:
            logger.setLevel(logging.DEBUG)

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        # https pool manager
        if configuration.proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file
            )

    def request(self, method, url, query_params=None, headers=None,
                body=None, post_params=None, files=None, _preload_content=True, _request_timeout=None):
        """
        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: if False, the urllib3.HTTPResponse object will be returned without
                                 reading/decoding response data. Default is True.
        :param _request_timeout: timeout setting for this request. If one number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT', 'PATCH', 'OPTIONS']
        headers = headers or {}

        timeout = None
        if _request_timeout:
            if isinstance(_request_timeout, (int, ) if PY3 else (int, long)):
                timeout = urllib3.Timeout(total=_request_timeout)
            elif isinstance(_request_timeout, tuple) and len(_request_timeout) == 2:
                timeout = urllib3.Timeout(connect=_request_timeout[0], read=_request_timeout[1])

        part_count = 0
        if files:
            if not body is None:
                part_count = 1
            part_count = part_count + len(files)
        if part_count > 0:
            headers['Content-Type'] = 'multipart/form-data'
        if 'Content-Type' not in headers:
            headers['Content-Type'] = 'application/json'

        logger.debug('>> ' + method + ' ' + url)
        if query_params:
            logger.debug('Query: ' + json.dumps(query_params))
        if post_params:
            logger.debug('Post parameters: %s', post_params)
        if headers:
            logger.debug('Headers: ' + json.dumps(headers))
        if not body is None and headers['Content-Type'] != 'multipart/form-data':
            logger.debug("Body: %s", body)
        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if query_params:
                    url += '?' + urlencode(query_params)
                if post_params and len(post_params) > 0:
                    headers['Content-Type'] = 'application/x-www-form-urlencoded'
                    r = self.pool_manager.request(method, url,
                                                  fields=post_params,
                                                  encode_multipart=False,
                                                  preload_content=_preload_content,
                                                  timeout=timeout,
                                                  headers=headers)
                elif part_count > 0:
                    del headers['Content-Type']
                    file_params = {}
                    if not body is None:
                        body = self.getBytes(body)
                        if not isinstance(body, bytes):
                            body = json.dumps(body)
                        file_params["pipeline"] = (None, body, "text/json")
                    if not files is None:
                        if type(files) is list:
                            for index, item in enumerate(files):
                                if type(item) == tuple:
                                    file_params[item[0]] = (item[0], self.getBytes(item[1]))
                                else:
                                    file_params["file" + str(index + 1)] = ("file" + str(index + 1), self.getBytes(item))
                        else:
                            for file_key in files:
                                if type(files[file_key]) == tuple:
                                    file_params[file_key] = (files[file_key][0], self.getBytes(files[file_key][1]))
                                else:
                                    file_params[file_key] = (file_key, self.getBytes(files[file_key]))
                    r = self.pool_manager.request(method, url,
                                              fields=file_params,
                                              encode_multipart=True,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
                elif not body is None:
                    request_body = None
                    if isinstance(body, bytes) or isinstance(body, str):
                        headers['Content-Type'] = 'application/octet-stream'
                        request_body = body
                    else:
                        headers['Content-Type'] = 'application/json'
                        request_body = json.dumps(body)
                    r = self.pool_manager.request(method, url,
                                              body=request_body,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
                else:
                    del headers['Content-Type']
                    r = self.pool_manager.request(method, url,
                                              body=body,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              fields=query_params,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        logger.debug('<< ' + str(r.status))
        if _preload_content:
            r = RESTResponse(r)
        
        response_type = ''
        if 'Content-Type' in r.getheaders():
            response_type = r.getheaders()['Content-Type']

        if 'text' in response_type or 'json' in response_type:
            logger.debug("response body: %s", r.data)
        elif r.data:
            logger.debug("response body: binary (%s bytes)", len(r.data))

        if not 200 <= r.status <= 299:
            raise ApiException(http_resp=r)

        return r

    def getBytes(self, data):
        read_op = getattr(data, 'read', None)
        if callable(read_op):
            return data.read()
        return data

    def GET(self, url, headers=None, query_params=None, _preload_content=True, _request_timeout=None):
        return self.request("GET", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def HEAD(self, url, headers=None, query_params=None, _preload_content=True, _request_timeout=None):
        return self.request("HEAD", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def OPTIONS(self, url, headers=None, query_params=None, post_params=None, body=None, files=None, _preload_content=True,
                _request_timeout=None):
        return self.request("OPTIONS", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            files=files,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def DELETE(self, url, headers=None, query_params=None, body=None, _preload_content=True, _request_timeout=None):
        return self.request("DELETE", url,
                            headers=headers,
                            query_params=query_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def POST(self, url, headers=None, query_params=None, post_params=None, body=None, files=None, _preload_content=True,
             _request_timeout=None):
        return self.request("POST", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            files=files,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PUT(self, url, headers=None, query_params=None, post_params=None, body=None, files=None, _preload_content=True,
            _request_timeout=None):
        return self.request("PUT", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            files=files,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PATCH(self, url, headers=None, query_params=None, post_params=None, body=None, files=None, _preload_content=True,
              _request_timeout=None):
        return self.request("PATCH", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            files=files,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)


class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            try:
                self.body = http_resp.data
            except:
                self.body = None
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """
        Custom error messages for exception
        """
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from asposeslidescloud.apis.api_base import ApiBase
from asposeslidescloud.api_client import ApiClient
from asposeslidescloud.models import *

class SlidesAsyncApi(ApiBase):

    def __init__(self, configuration = None, app_sid = None, app_key = None):
        super(SlidesAsyncApi, self).__init__(configuration, app_sid, app_key)

    def download(self, path, storage_name = None, version_id = None, **kwargs):  # noqa: E501
        """download  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(path, storage_name, version_id, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param path 
        :param storage_name 
        :param version_id 
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.download_with_http_info(path, storage_name, version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_with_http_info(path, storage_name, version_id, **kwargs)  # noqa: E501
            return data

    def download_with_http_info(self, path, storage_name = None, version_id = None, **kwargs):  # noqa: E501
        """download  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.download_with_http_info(path, storage_name, version_id, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param path 
        :param storage_name 
        :param version_id 
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if not path:
            raise ValueError("Missing the required parameter `path` when calling `download`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['path'] = path  # noqa: E501

        query_params = []
        if storage_name:
            query_params.append(('storageName', storage_name))  # noqa: E501
        if version_id:
            query_params.append(('versionId', version_id))  # noqa: E501

        header_params = {}

        form_params = []
        param_files = {}

        body_params = None

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/storage/file/{path}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_operation_result(self, id, **kwargs):  # noqa: E501
        """get_operation_result  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(id, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param id 
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.get_operation_result_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_operation_result_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_operation_result_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_operation_result  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.get_operation_result_with_http_info(id, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param id 
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_operation_result" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if not id:
            raise ValueError("Missing the required parameter `id` when calling `get_operation_result`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['id'] = id  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        param_files = {}

        body_params = None

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/{id}/result', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_operation_status(self, id, **kwargs):  # noqa: E501
        """get_operation_status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(id, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param id 
        :return: Operation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.get_operation_status_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_operation_status_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_operation_status_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_operation_status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.get_operation_status_with_http_info(id, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param id 
        :return: Operation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_operation_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if not id:
            raise ValueError("Missing the required parameter `id` when calling `get_operation_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['id'] = id  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        param_files = {}

        body_params = None

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='Operation',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_convert(self, document, format, password = None, storage = None, fonts_folder = None, slides = None, options = None, **kwargs):  # noqa: E501
        """start_convert  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(document, format, password, storage, fonts_folder, slides, options, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param document Document data.
        :param format 
        :param password 
        :param storage 
        :param fonts_folder 
        :param slides 
        :param options 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_convert_with_http_info(document, format, password, storage, fonts_folder, slides, options, **kwargs)  # noqa: E501
        else:
            (data) = self.start_convert_with_http_info(document, format, password, storage, fonts_folder, slides, options, **kwargs)  # noqa: E501
            return data

    def start_convert_with_http_info(self, document, format, password = None, storage = None, fonts_folder = None, slides = None, options = None, **kwargs):  # noqa: E501
        """start_convert  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_convert_with_http_info(document, format, password, storage, fonts_folder, slides, options, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param document Document data.
        :param format 
        :param password 
        :param storage 
        :param fonts_folder 
        :param slides 
        :param options 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_convert" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'document' is set
        if not document:
            raise ValueError("Missing the required parameter `document` when calling `start_convert`")  # noqa: E501
        # verify the required parameter 'format' is set
        if not format:
            raise ValueError("Missing the required parameter `format` when calling `start_convert`")  # noqa: E501
        # verify the value of parameter 'format' is valid
        if not format.upper() in ExportFormat.__dict__:
            raise ValueError("Invalid value for parameter `format` when calling `start_convert`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['format'] = format  # noqa: E501

        query_params = []
        if storage:
            query_params.append(('storage', storage))  # noqa: E501
        if fonts_folder:
            query_params.append(('fontsFolder', fonts_folder))  # noqa: E501
        if slides:
            query_params.append(('slides', slides))  # noqa: E501
            collection_formats['slides'] = ''  # noqa: E501

        header_params = {}
        if password:
            header_params['password'] = password  # noqa: E501

        form_params = []
        param_files = {}
        if document:
            param_files['document'] = document  # noqa: E501

        body_params = None
        if options:
            body_params = options

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/convert/{format}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_convert_and_save(self, document, format, out_path, password = None, storage = None, fonts_folder = None, slides = None, options = None, **kwargs):  # noqa: E501
        """start_convert_and_save  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(document, format, out_path, password, storage, fonts_folder, slides, options, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param document Document data.
        :param format 
        :param out_path 
        :param password 
        :param storage 
        :param fonts_folder 
        :param slides 
        :param options 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_convert_and_save_with_http_info(document, format, out_path, password, storage, fonts_folder, slides, options, **kwargs)  # noqa: E501
        else:
            (data) = self.start_convert_and_save_with_http_info(document, format, out_path, password, storage, fonts_folder, slides, options, **kwargs)  # noqa: E501
            return data

    def start_convert_and_save_with_http_info(self, document, format, out_path, password = None, storage = None, fonts_folder = None, slides = None, options = None, **kwargs):  # noqa: E501
        """start_convert_and_save  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_convert_and_save_with_http_info(document, format, out_path, password, storage, fonts_folder, slides, options, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param document Document data.
        :param format 
        :param out_path 
        :param password 
        :param storage 
        :param fonts_folder 
        :param slides 
        :param options 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_convert_and_save" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'document' is set
        if not document:
            raise ValueError("Missing the required parameter `document` when calling `start_convert_and_save`")  # noqa: E501
        # verify the required parameter 'format' is set
        if not format:
            raise ValueError("Missing the required parameter `format` when calling `start_convert_and_save`")  # noqa: E501
        # verify the value of parameter 'format' is valid
        if not format.upper() in ExportFormat.__dict__:
            raise ValueError("Invalid value for parameter `format` when calling `start_convert_and_save`")  # noqa: E501
        # verify the required parameter 'out_path' is set
        if not out_path:
            raise ValueError("Missing the required parameter `out_path` when calling `start_convert_and_save`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['format'] = format  # noqa: E501

        query_params = []
        if out_path:
            query_params.append(('outPath', out_path))  # noqa: E501
        if storage:
            query_params.append(('storage', storage))  # noqa: E501
        if fonts_folder:
            query_params.append(('fontsFolder', fonts_folder))  # noqa: E501
        if slides:
            query_params.append(('slides', slides))  # noqa: E501
            collection_formats['slides'] = ''  # noqa: E501

        header_params = {}
        if password:
            header_params['password'] = password  # noqa: E501

        form_params = []
        param_files = {}
        if document:
            param_files['document'] = document  # noqa: E501

        body_params = None
        if options:
            body_params = options

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/convert/{format}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_download_presentation(self, name, format, options = None, password = None, folder = None, storage = None, fonts_folder = None, slides = None, **kwargs):  # noqa: E501
        """start_download_presentation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(name, format, options, password, folder, storage, fonts_folder, slides, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param name 
        :param format 
        :param options 
        :param password 
        :param folder 
        :param storage 
        :param fonts_folder 
        :param slides 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_download_presentation_with_http_info(name, format, options, password, folder, storage, fonts_folder, slides, **kwargs)  # noqa: E501
        else:
            (data) = self.start_download_presentation_with_http_info(name, format, options, password, folder, storage, fonts_folder, slides, **kwargs)  # noqa: E501
            return data

    def start_download_presentation_with_http_info(self, name, format, options = None, password = None, folder = None, storage = None, fonts_folder = None, slides = None, **kwargs):  # noqa: E501
        """start_download_presentation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_download_presentation_with_http_info(name, format, options, password, folder, storage, fonts_folder, slides, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param name 
        :param format 
        :param options 
        :param password 
        :param folder 
        :param storage 
        :param fonts_folder 
        :param slides 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_download_presentation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if not name:
            raise ValueError("Missing the required parameter `name` when calling `start_download_presentation`")  # noqa: E501
        # verify the required parameter 'format' is set
        if not format:
            raise ValueError("Missing the required parameter `format` when calling `start_download_presentation`")  # noqa: E501
        # verify the value of parameter 'format' is valid
        if not format.upper() in ExportFormat.__dict__:
            raise ValueError("Invalid value for parameter `format` when calling `start_download_presentation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['name'] = name  # noqa: E501
        path_params['format'] = format  # noqa: E501

        query_params = []
        if folder:
            query_params.append(('folder', folder))  # noqa: E501
        if storage:
            query_params.append(('storage', storage))  # noqa: E501
        if fonts_folder:
            query_params.append(('fontsFolder', fonts_folder))  # noqa: E501
        if slides:
            query_params.append(('slides', slides))  # noqa: E501
            collection_formats['slides'] = ''  # noqa: E501

        header_params = {}
        if password:
            header_params['password'] = password  # noqa: E501

        form_params = []
        param_files = {}

        body_params = None
        if options:
            body_params = options

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/{name}/{format}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_merge(self, files = None, request = None, storage = None, **kwargs):  # noqa: E501
        """start_merge  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(files, request, storage, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param files Files to merge
        :param request 
        :param storage 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_merge_with_http_info(files, request, storage, **kwargs)  # noqa: E501
        else:
            (data) = self.start_merge_with_http_info(files, request, storage, **kwargs)  # noqa: E501
            return data

    def start_merge_with_http_info(self, files = None, request = None, storage = None, **kwargs):  # noqa: E501
        """start_merge  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_merge_with_http_info(files, request, storage, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param files Files to merge
        :param request 
        :param storage 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_merge" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if storage:
            query_params.append(('storage', storage))  # noqa: E501

        header_params = {}

        form_params = []
        param_files = {}
        param_files = files

        body_params = None
        if request:
            body_params = request

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/merge', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_merge_and_save(self, out_path, files = None, request = None, storage = None, **kwargs):  # noqa: E501
        """start_merge_and_save  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(out_path, files, request, storage, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param out_path 
        :param files Files to merge
        :param request 
        :param storage 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_merge_and_save_with_http_info(out_path, files, request, storage, **kwargs)  # noqa: E501
        else:
            (data) = self.start_merge_and_save_with_http_info(out_path, files, request, storage, **kwargs)  # noqa: E501
            return data

    def start_merge_and_save_with_http_info(self, out_path, files = None, request = None, storage = None, **kwargs):  # noqa: E501
        """start_merge_and_save  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_merge_and_save_with_http_info(out_path, files, request, storage, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param out_path 
        :param files Files to merge
        :param request 
        :param storage 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_merge_and_save" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'out_path' is set
        if not out_path:
            raise ValueError("Missing the required parameter `out_path` when calling `start_merge_and_save`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if out_path:
            query_params.append(('outPath', out_path))  # noqa: E501
        if storage:
            query_params.append(('storage', storage))  # noqa: E501

        header_params = {}

        form_params = []
        param_files = {}
        param_files = files

        body_params = None
        if request:
            body_params = request

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/merge', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_save_presentation(self, name, format, out_path, options = None, password = None, folder = None, storage = None, fonts_folder = None, slides = None, **kwargs):  # noqa: E501
        """start_save_presentation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(name, format, out_path, options, password, folder, storage, fonts_folder, slides, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param name 
        :param format 
        :param out_path 
        :param options 
        :param password 
        :param folder 
        :param storage 
        :param fonts_folder 
        :param slides 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_save_presentation_with_http_info(name, format, out_path, options, password, folder, storage, fonts_folder, slides, **kwargs)  # noqa: E501
        else:
            (data) = self.start_save_presentation_with_http_info(name, format, out_path, options, password, folder, storage, fonts_folder, slides, **kwargs)  # noqa: E501
            return data

    def start_save_presentation_with_http_info(self, name, format, out_path, options = None, password = None, folder = None, storage = None, fonts_folder = None, slides = None, **kwargs):  # noqa: E501
        """start_save_presentation  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_save_presentation_with_http_info(name, format, out_path, options, password, folder, storage, fonts_folder, slides, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param name 
        :param format 
        :param out_path 
        :param options 
        :param password 
        :param folder 
        :param storage 
        :param fonts_folder 
        :param slides 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_save_presentation" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if not name:
            raise ValueError("Missing the required parameter `name` when calling `start_save_presentation`")  # noqa: E501
        # verify the required parameter 'format' is set
        if not format:
            raise ValueError("Missing the required parameter `format` when calling `start_save_presentation`")  # noqa: E501
        # verify the value of parameter 'format' is valid
        if not format.upper() in ExportFormat.__dict__:
            raise ValueError("Invalid value for parameter `format` when calling `start_save_presentation`")  # noqa: E501
        # verify the required parameter 'out_path' is set
        if not out_path:
            raise ValueError("Missing the required parameter `out_path` when calling `start_save_presentation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['name'] = name  # noqa: E501
        path_params['format'] = format  # noqa: E501

        query_params = []
        if out_path:
            query_params.append(('outPath', out_path))  # noqa: E501
        if folder:
            query_params.append(('folder', folder))  # noqa: E501
        if storage:
            query_params.append(('storage', storage))  # noqa: E501
        if fonts_folder:
            query_params.append(('fontsFolder', fonts_folder))  # noqa: E501
        if slides:
            query_params.append(('slides', slides))  # noqa: E501
            collection_formats['slides'] = ''  # noqa: E501

        header_params = {}
        if password:
            header_params['password'] = password  # noqa: E501

        form_params = []
        param_files = {}

        body_params = None
        if options:
            body_params = options

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/{name}/{format}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_split(self, name, format, options = None, width = None, height = None, _from = None, to = None, dest_folder = None, password = None, folder = None, storage = None, fonts_folder = None, **kwargs):  # noqa: E501
        """start_split  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(name, format, options, width, height, _from, to, dest_folder, password, folder, storage, fonts_folder, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param name 
        :param format 
        :param options 
        :param width 
        :param height 
        :param _from 
        :param to 
        :param dest_folder 
        :param password 
        :param folder 
        :param storage 
        :param fonts_folder 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_split_with_http_info(name, format, options, width, height, _from, to, dest_folder, password, folder, storage, fonts_folder, **kwargs)  # noqa: E501
        else:
            (data) = self.start_split_with_http_info(name, format, options, width, height, _from, to, dest_folder, password, folder, storage, fonts_folder, **kwargs)  # noqa: E501
            return data

    def start_split_with_http_info(self, name, format, options = None, width = None, height = None, _from = None, to = None, dest_folder = None, password = None, folder = None, storage = None, fonts_folder = None, **kwargs):  # noqa: E501
        """start_split  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_split_with_http_info(name, format, options, width, height, _from, to, dest_folder, password, folder, storage, fonts_folder, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param name 
        :param format 
        :param options 
        :param width 
        :param height 
        :param _from 
        :param to 
        :param dest_folder 
        :param password 
        :param folder 
        :param storage 
        :param fonts_folder 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_split" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if not name:
            raise ValueError("Missing the required parameter `name` when calling `start_split`")  # noqa: E501
        # verify the required parameter 'format' is set
        if not format:
            raise ValueError("Missing the required parameter `format` when calling `start_split`")  # noqa: E501
        # verify the value of parameter 'format' is valid
        if not format.upper() in SlideExportFormat.__dict__:
            raise ValueError("Invalid value for parameter `format` when calling `start_split`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['name'] = name  # noqa: E501
        path_params['format'] = format  # noqa: E501

        query_params = []
        if width:
            query_params.append(('width', width))  # noqa: E501
        if height:
            query_params.append(('height', height))  # noqa: E501
        if _from:
            query_params.append(('from', _from))  # noqa: E501
        if to:
            query_params.append(('to', to))  # noqa: E501
        if dest_folder:
            query_params.append(('destFolder', dest_folder))  # noqa: E501
        if folder:
            query_params.append(('folder', folder))  # noqa: E501
        if storage:
            query_params.append(('storage', storage))  # noqa: E501
        if fonts_folder:
            query_params.append(('fontsFolder', fonts_folder))  # noqa: E501

        header_params = {}
        if password:
            header_params['password'] = password  # noqa: E501

        form_params = []
        param_files = {}

        body_params = None
        if options:
            body_params = options

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/{name}/split/{format}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_upload_and_split(self, document, format, dest_folder = None, width = None, height = None, _from = None, to = None, password = None, storage = None, fonts_folder = None, options = None, **kwargs):  # noqa: E501
        """start_upload_and_split  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(document, format, dest_folder, width, height, _from, to, password, storage, fonts_folder, options, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param document Document data.
        :param format 
        :param dest_folder 
        :param width 
        :param height 
        :param _from 
        :param to 
        :param password 
        :param storage 
        :param fonts_folder 
        :param options 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.start_upload_and_split_with_http_info(document, format, dest_folder, width, height, _from, to, password, storage, fonts_folder, options, **kwargs)  # noqa: E501
        else:
            (data) = self.start_upload_and_split_with_http_info(document, format, dest_folder, width, height, _from, to, password, storage, fonts_folder, options, **kwargs)  # noqa: E501
            return data

    def start_upload_and_split_with_http_info(self, document, format, dest_folder = None, width = None, height = None, _from = None, to = None, password = None, storage = None, fonts_folder = None, options = None, **kwargs):  # noqa: E501
        """start_upload_and_split  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.start_upload_and_split_with_http_info(document, format, dest_folder, width, height, _from, to, password, storage, fonts_folder, options, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param document Document data.
        :param format 
        :param dest_folder 
        :param width 
        :param height 
        :param _from 
        :param to 
        :param password 
        :param storage 
        :param fonts_folder 
        :param options 
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_upload_and_split" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'document' is set
        if not document:
            raise ValueError("Missing the required parameter `document` when calling `start_upload_and_split`")  # noqa: E501
        # verify the required parameter 'format' is set
        if not format:
            raise ValueError("Missing the required parameter `format` when calling `start_upload_and_split`")  # noqa: E501
        # verify the value of parameter 'format' is valid
        if not format.upper() in SlideExportFormat.__dict__:
            raise ValueError("Invalid value for parameter `format` when calling `start_upload_and_split`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['format'] = format  # noqa: E501

        query_params = []
        if dest_folder:
            query_params.append(('destFolder', dest_folder))  # noqa: E501
        if width:
            query_params.append(('width', width))  # noqa: E501
        if height:
            query_params.append(('height', height))  # noqa: E501
        if _from:
            query_params.append(('from', _from))  # noqa: E501
        if to:
            query_params.append(('to', to))  # noqa: E501
        if storage:
            query_params.append(('storage', storage))  # noqa: E501
        if fonts_folder:
            query_params.append(('fontsFolder', fonts_folder))  # noqa: E501

        header_params = {}
        if password:
            header_params['password'] = password  # noqa: E501

        form_params = []
        param_files = {}
        if document:
            param_files['document'] = document  # noqa: E501

        body_params = None
        if options:
            body_params = options

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/split/{format}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload(self, path, file, storage_name = None, **kwargs):  # noqa: E501
        """upload  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.(path, file, storage_name, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param path 
        :param file File to upload
        :param storage_name 
        :return: FilesUploadResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('is_async'):
            return self.upload_with_http_info(path, file, storage_name, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_with_http_info(path, file, storage_name, **kwargs)  # noqa: E501
            return data

    def upload_with_http_info(self, path, file, storage_name = None, **kwargs):  # noqa: E501
        """upload  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass is_async=True
        >>> thread = api.upload_with_http_info(path, file, storage_name, is_async=True)
        >>> result = thread.get()

        :param is_async bool
        :param path 
        :param file File to upload
        :param storage_name 
        :return: FilesUploadResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('is_async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if not path:
            raise ValueError("Missing the required parameter `path` when calling `upload`")  # noqa: E501
        # verify the required parameter 'file' is set
        if not file:
            raise ValueError("Missing the required parameter `file` when calling `upload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        path_params['path'] = path  # noqa: E501

        query_params = []
        if storage_name:
            query_params.append(('storageName', storage_name))  # noqa: E501

        header_params = {}

        form_params = []
        param_files = {}
        if file:
            param_files['file'] = file  # noqa: E501

        body_params = None

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JWT']  # noqa: E501

        return self.api_client.call_api(
            '/slides/async/storage/file/{path}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=param_files,
            response_type='FilesUploadResult',  # noqa: E501
            auth_settings=auth_settings,
            is_async=params.get('is_async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', False),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class SlideShowTransition(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'advance_after': 'bool',
        'advance_after_time': 'int',
        'advance_on_click': 'bool',
        'sound_is_built_in': 'bool',
        'sound_loop': 'bool',
        'sound_mode': 'str',
        'sound_name': 'str',
        'speed': 'str',
        'corner_direction': 'str',
        'eight_direction': 'str',
        'in_out_direction': 'str',
        'has_bounce': 'bool',
        'side_direction': 'str',
        'pattern': 'str',
        'left_right_direction': 'str',
        'morph_type': 'str',
        'from_black': 'bool',
        'orientation_direction': 'str',
        'through_black': 'bool',
        'corner_and_center_direction': 'str',
        'shred_pattern': 'str',
        'orientation': 'str',
        'spokes': 'int'
    }

    attribute_map = {
        'type': 'type',
        'advance_after': 'advanceAfter',
        'advance_after_time': 'advanceAfterTime',
        'advance_on_click': 'advanceOnClick',
        'sound_is_built_in': 'soundIsBuiltIn',
        'sound_loop': 'soundLoop',
        'sound_mode': 'soundMode',
        'sound_name': 'soundName',
        'speed': 'speed',
        'corner_direction': 'cornerDirection',
        'eight_direction': 'eightDirection',
        'in_out_direction': 'inOutDirection',
        'has_bounce': 'hasBounce',
        'side_direction': 'sideDirection',
        'pattern': 'pattern',
        'left_right_direction': 'leftRightDirection',
        'morph_type': 'morphType',
        'from_black': 'fromBlack',
        'orientation_direction': 'orientationDirection',
        'through_black': 'throughBlack',
        'corner_and_center_direction': 'cornerAndCenterDirection',
        'shred_pattern': 'shredPattern',
        'orientation': 'orientation',
        'spokes': 'spokes'
    }

    type_determiners = {
    }

    def __init__(self, type=None, advance_after=None, advance_after_time=None, advance_on_click=None, sound_is_built_in=None, sound_loop=None, sound_mode=None, sound_name=None, speed=None, corner_direction=None, eight_direction=None, in_out_direction=None, has_bounce=None, side_direction=None, pattern=None, left_right_direction=None, morph_type=None, from_black=None, orientation_direction=None, through_black=None, corner_and_center_direction=None, shred_pattern=None, orientation=None, spokes=None):  # noqa: E501
        """SlideShowTransition - a model defined in Swagger"""  # noqa: E501

        self._type = None
        self._advance_after = None
        self._advance_after_time = None
        self._advance_on_click = None
        self._sound_is_built_in = None
        self._sound_loop = None
        self._sound_mode = None
        self._sound_name = None
        self._speed = None
        self._corner_direction = None
        self._eight_direction = None
        self._in_out_direction = None
        self._has_bounce = None
        self._side_direction = None
        self._pattern = None
        self._left_right_direction = None
        self._morph_type = None
        self._from_black = None
        self._orientation_direction = None
        self._through_black = None
        self._corner_and_center_direction = None
        self._shred_pattern = None
        self._orientation = None
        self._spokes = None

        if type is not None:
            self.type = type
        if advance_after is not None:
            self.advance_after = advance_after
        if advance_after_time is not None:
            self.advance_after_time = advance_after_time
        if advance_on_click is not None:
            self.advance_on_click = advance_on_click
        if sound_is_built_in is not None:
            self.sound_is_built_in = sound_is_built_in
        if sound_loop is not None:
            self.sound_loop = sound_loop
        if sound_mode is not None:
            self.sound_mode = sound_mode
        if sound_name is not None:
            self.sound_name = sound_name
        if speed is not None:
            self.speed = speed
        if corner_direction is not None:
            self.corner_direction = corner_direction
        if eight_direction is not None:
            self.eight_direction = eight_direction
        if in_out_direction is not None:
            self.in_out_direction = in_out_direction
        if has_bounce is not None:
            self.has_bounce = has_bounce
        if side_direction is not None:
            self.side_direction = side_direction
        if pattern is not None:
            self.pattern = pattern
        if left_right_direction is not None:
            self.left_right_direction = left_right_direction
        if morph_type is not None:
            self.morph_type = morph_type
        if from_black is not None:
            self.from_black = from_black
        if orientation_direction is not None:
            self.orientation_direction = orientation_direction
        if through_black is not None:
            self.through_black = through_black
        if corner_and_center_direction is not None:
            self.corner_and_center_direction = corner_and_center_direction
        if shred_pattern is not None:
            self.shred_pattern = shred_pattern
        if orientation is not None:
            self.orientation = orientation
        if spokes is not None:
            self.spokes = spokes

    @property
    def type(self):
        """Gets the type of this SlideShowTransition.  # noqa: E501

        Transition Type  # noqa: E501

        :return: The type of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SlideShowTransition.

        Transition Type  # noqa: E501

        :param type: The type of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if type is not None:
            allowed_values = ["None", "Blinds", "Checker", "Circle", "Comb", "Cover", "Cut", "Diamond", "Dissolve", "Fade", "Newsflash", "Plus", "Pull", "Push", "Random", "RandomBar", "Split", "Strips", "Wedge", "Wheel", "Wipe", "Zoom", "Vortex", "Switch", "Flip", "Ripple", "Honeycomb", "Cube", "Box", "Rotate", "Orbit", "Doors", "Window", "Ferris", "Gallery", "Conveyor", "Pan", "Glitter", "Warp", "Flythrough", "Flash", "Shred", "Reveal", "WheelReverse", "FallOver", "Drape", "Curtains", "Wind", "Prestige", "Fracture", "Crush", "PeelOff", "PageCurlDouble", "PageCurlSingle", "Airplane", "Origami", "Morph"]  # noqa: E501
            if type.isdigit():
                int_type = int(type)
                if int_type < 0 or int_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                        .format(type, allowed_values)
                    )
                self._type = allowed_values[int_type]
                return
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                    .format(type, allowed_values)
                )
        self._type = type

    @property
    def advance_after(self):
        """Gets the advance_after of this SlideShowTransition.  # noqa: E501

        Advance After  # noqa: E501

        :return: The advance_after of this SlideShowTransition.  # noqa: E501
        :rtype: bool
        """
        return self._advance_after

    @advance_after.setter
    def advance_after(self, advance_after):
        """Sets the advance_after of this SlideShowTransition.

        Advance After  # noqa: E501

        :param advance_after: The advance_after of this SlideShowTransition.  # noqa: E501
        :type: bool
        """
        self._advance_after = advance_after

    @property
    def advance_after_time(self):
        """Gets the advance_after_time of this SlideShowTransition.  # noqa: E501

        Advance After Time  # noqa: E501

        :return: The advance_after_time of this SlideShowTransition.  # noqa: E501
        :rtype: int
        """
        return self._advance_after_time

    @advance_after_time.setter
    def advance_after_time(self, advance_after_time):
        """Sets the advance_after_time of this SlideShowTransition.

        Advance After Time  # noqa: E501

        :param advance_after_time: The advance_after_time of this SlideShowTransition.  # noqa: E501
        :type: int
        """
        self._advance_after_time = advance_after_time

    @property
    def advance_on_click(self):
        """Gets the advance_on_click of this SlideShowTransition.  # noqa: E501

        Advance On Click  # noqa: E501

        :return: The advance_on_click of this SlideShowTransition.  # noqa: E501
        :rtype: bool
        """
        return self._advance_on_click

    @advance_on_click.setter
    def advance_on_click(self, advance_on_click):
        """Sets the advance_on_click of this SlideShowTransition.

        Advance On Click  # noqa: E501

        :param advance_on_click: The advance_on_click of this SlideShowTransition.  # noqa: E501
        :type: bool
        """
        self._advance_on_click = advance_on_click

    @property
    def sound_is_built_in(self):
        """Gets the sound_is_built_in of this SlideShowTransition.  # noqa: E501

        Sound Is Built In  # noqa: E501

        :return: The sound_is_built_in of this SlideShowTransition.  # noqa: E501
        :rtype: bool
        """
        return self._sound_is_built_in

    @sound_is_built_in.setter
    def sound_is_built_in(self, sound_is_built_in):
        """Sets the sound_is_built_in of this SlideShowTransition.

        Sound Is Built In  # noqa: E501

        :param sound_is_built_in: The sound_is_built_in of this SlideShowTransition.  # noqa: E501
        :type: bool
        """
        self._sound_is_built_in = sound_is_built_in

    @property
    def sound_loop(self):
        """Gets the sound_loop of this SlideShowTransition.  # noqa: E501

        Sound Loop  # noqa: E501

        :return: The sound_loop of this SlideShowTransition.  # noqa: E501
        :rtype: bool
        """
        return self._sound_loop

    @sound_loop.setter
    def sound_loop(self, sound_loop):
        """Sets the sound_loop of this SlideShowTransition.

        Sound Loop  # noqa: E501

        :param sound_loop: The sound_loop of this SlideShowTransition.  # noqa: E501
        :type: bool
        """
        self._sound_loop = sound_loop

    @property
    def sound_mode(self):
        """Gets the sound_mode of this SlideShowTransition.  # noqa: E501

        Sound Mode  # noqa: E501

        :return: The sound_mode of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._sound_mode

    @sound_mode.setter
    def sound_mode(self, sound_mode):
        """Sets the sound_mode of this SlideShowTransition.

        Sound Mode  # noqa: E501

        :param sound_mode: The sound_mode of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if sound_mode is not None:
            allowed_values = ["StartSound", "StopPrevoiusSound", "NotDefined"]  # noqa: E501
            if sound_mode.isdigit():
                int_sound_mode = int(sound_mode)
                if int_sound_mode < 0 or int_sound_mode >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `sound_mode` ({0}), must be one of {1}"  # noqa: E501
                        .format(sound_mode, allowed_values)
                    )
                self._sound_mode = allowed_values[int_sound_mode]
                return
            if sound_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `sound_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(sound_mode, allowed_values)
                )
        self._sound_mode = sound_mode

    @property
    def sound_name(self):
        """Gets the sound_name of this SlideShowTransition.  # noqa: E501

        Sound Name  # noqa: E501

        :return: The sound_name of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._sound_name

    @sound_name.setter
    def sound_name(self, sound_name):
        """Sets the sound_name of this SlideShowTransition.

        Sound Name  # noqa: E501

        :param sound_name: The sound_name of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        self._sound_name = sound_name

    @property
    def speed(self):
        """Gets the speed of this SlideShowTransition.  # noqa: E501

        Speed  # noqa: E501

        :return: The speed of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this SlideShowTransition.

        Speed  # noqa: E501

        :param speed: The speed of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if speed is not None:
            allowed_values = ["Fast", "Medium", "Slow"]  # noqa: E501
            if speed.isdigit():
                int_speed = int(speed)
                if int_speed < 0 or int_speed >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `speed` ({0}), must be one of {1}"  # noqa: E501
                        .format(speed, allowed_values)
                    )
                self._speed = allowed_values[int_speed]
                return
            if speed not in allowed_values:
                raise ValueError(
                    "Invalid value for `speed` ({0}), must be one of {1}"  # noqa: E501
                    .format(speed, allowed_values)
                )
        self._speed = speed

    @property
    def corner_direction(self):
        """Gets the corner_direction of this SlideShowTransition.  # noqa: E501

        Corner Direction.  # noqa: E501

        :return: The corner_direction of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._corner_direction

    @corner_direction.setter
    def corner_direction(self, corner_direction):
        """Sets the corner_direction of this SlideShowTransition.

        Corner Direction.  # noqa: E501

        :param corner_direction: The corner_direction of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if corner_direction is not None:
            allowed_values = ["LeftDown", "LeftUp", "RightDown", "RightUp"]  # noqa: E501
            if corner_direction.isdigit():
                int_corner_direction = int(corner_direction)
                if int_corner_direction < 0 or int_corner_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `corner_direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(corner_direction, allowed_values)
                    )
                self._corner_direction = allowed_values[int_corner_direction]
                return
            if corner_direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `corner_direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(corner_direction, allowed_values)
                )
        self._corner_direction = corner_direction

    @property
    def eight_direction(self):
        """Gets the eight_direction of this SlideShowTransition.  # noqa: E501

        Eight Direction.  # noqa: E501

        :return: The eight_direction of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._eight_direction

    @eight_direction.setter
    def eight_direction(self, eight_direction):
        """Sets the eight_direction of this SlideShowTransition.

        Eight Direction.  # noqa: E501

        :param eight_direction: The eight_direction of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if eight_direction is not None:
            allowed_values = ["LeftDown", "LeftUp", "RightDown", "RightUp", "Left", "Up", "Down", "Right"]  # noqa: E501
            if eight_direction.isdigit():
                int_eight_direction = int(eight_direction)
                if int_eight_direction < 0 or int_eight_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `eight_direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(eight_direction, allowed_values)
                    )
                self._eight_direction = allowed_values[int_eight_direction]
                return
            if eight_direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `eight_direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(eight_direction, allowed_values)
                )
        self._eight_direction = eight_direction

    @property
    def in_out_direction(self):
        """Gets the in_out_direction of this SlideShowTransition.  # noqa: E501

        In/Out Direction.  # noqa: E501

        :return: The in_out_direction of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._in_out_direction

    @in_out_direction.setter
    def in_out_direction(self, in_out_direction):
        """Sets the in_out_direction of this SlideShowTransition.

        In/Out Direction.  # noqa: E501

        :param in_out_direction: The in_out_direction of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if in_out_direction is not None:
            allowed_values = ["In", "Out"]  # noqa: E501
            if in_out_direction.isdigit():
                int_in_out_direction = int(in_out_direction)
                if int_in_out_direction < 0 or int_in_out_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `in_out_direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(in_out_direction, allowed_values)
                    )
                self._in_out_direction = allowed_values[int_in_out_direction]
                return
            if in_out_direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `in_out_direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(in_out_direction, allowed_values)
                )
        self._in_out_direction = in_out_direction

    @property
    def has_bounce(self):
        """Gets the has_bounce of this SlideShowTransition.  # noqa: E501

        Has Bounce.  # noqa: E501

        :return: The has_bounce of this SlideShowTransition.  # noqa: E501
        :rtype: bool
        """
        return self._has_bounce

    @has_bounce.setter
    def has_bounce(self, has_bounce):
        """Sets the has_bounce of this SlideShowTransition.

        Has Bounce.  # noqa: E501

        :param has_bounce: The has_bounce of this SlideShowTransition.  # noqa: E501
        :type: bool
        """
        self._has_bounce = has_bounce

    @property
    def side_direction(self):
        """Gets the side_direction of this SlideShowTransition.  # noqa: E501

        Side Direction.  # noqa: E501

        :return: The side_direction of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._side_direction

    @side_direction.setter
    def side_direction(self, side_direction):
        """Sets the side_direction of this SlideShowTransition.

        Side Direction.  # noqa: E501

        :param side_direction: The side_direction of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if side_direction is not None:
            allowed_values = ["Left", "Up", "Down", "Right"]  # noqa: E501
            if side_direction.isdigit():
                int_side_direction = int(side_direction)
                if int_side_direction < 0 or int_side_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `side_direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(side_direction, allowed_values)
                    )
                self._side_direction = allowed_values[int_side_direction]
                return
            if side_direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `side_direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(side_direction, allowed_values)
                )
        self._side_direction = side_direction

    @property
    def pattern(self):
        """Gets the pattern of this SlideShowTransition.  # noqa: E501

        Pattern.  # noqa: E501

        :return: The pattern of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this SlideShowTransition.

        Pattern.  # noqa: E501

        :param pattern: The pattern of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if pattern is not None:
            allowed_values = ["Diamond", "Hexagon"]  # noqa: E501
            if pattern.isdigit():
                int_pattern = int(pattern)
                if int_pattern < 0 or int_pattern >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `pattern` ({0}), must be one of {1}"  # noqa: E501
                        .format(pattern, allowed_values)
                    )
                self._pattern = allowed_values[int_pattern]
                return
            if pattern not in allowed_values:
                raise ValueError(
                    "Invalid value for `pattern` ({0}), must be one of {1}"  # noqa: E501
                    .format(pattern, allowed_values)
                )
        self._pattern = pattern

    @property
    def left_right_direction(self):
        """Gets the left_right_direction of this SlideShowTransition.  # noqa: E501

        Left/Right Direction.  # noqa: E501

        :return: The left_right_direction of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._left_right_direction

    @left_right_direction.setter
    def left_right_direction(self, left_right_direction):
        """Sets the left_right_direction of this SlideShowTransition.

        Left/Right Direction.  # noqa: E501

        :param left_right_direction: The left_right_direction of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if left_right_direction is not None:
            allowed_values = ["Left", "Right"]  # noqa: E501
            if left_right_direction.isdigit():
                int_left_right_direction = int(left_right_direction)
                if int_left_right_direction < 0 or int_left_right_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `left_right_direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(left_right_direction, allowed_values)
                    )
                self._left_right_direction = allowed_values[int_left_right_direction]
                return
            if left_right_direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `left_right_direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(left_right_direction, allowed_values)
                )
        self._left_right_direction = left_right_direction

    @property
    def morph_type(self):
        """Gets the morph_type of this SlideShowTransition.  # noqa: E501

        Morph Type.  # noqa: E501

        :return: The morph_type of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._morph_type

    @morph_type.setter
    def morph_type(self, morph_type):
        """Sets the morph_type of this SlideShowTransition.

        Morph Type.  # noqa: E501

        :param morph_type: The morph_type of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if morph_type is not None:
            allowed_values = ["ByObject", "ByWord", "ByChar"]  # noqa: E501
            if morph_type.isdigit():
                int_morph_type = int(morph_type)
                if int_morph_type < 0 or int_morph_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `morph_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(morph_type, allowed_values)
                    )
                self._morph_type = allowed_values[int_morph_type]
                return
            if morph_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `morph_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(morph_type, allowed_values)
                )
        self._morph_type = morph_type

    @property
    def from_black(self):
        """Gets the from_black of this SlideShowTransition.  # noqa: E501

        From Black.  # noqa: E501

        :return: The from_black of this SlideShowTransition.  # noqa: E501
        :rtype: bool
        """
        return self._from_black

    @from_black.setter
    def from_black(self, from_black):
        """Sets the from_black of this SlideShowTransition.

        From Black.  # noqa: E501

        :param from_black: The from_black of this SlideShowTransition.  # noqa: E501
        :type: bool
        """
        self._from_black = from_black

    @property
    def orientation_direction(self):
        """Gets the orientation_direction of this SlideShowTransition.  # noqa: E501

        Orientation Direction.  # noqa: E501

        :return: The orientation_direction of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._orientation_direction

    @orientation_direction.setter
    def orientation_direction(self, orientation_direction):
        """Sets the orientation_direction of this SlideShowTransition.

        Orientation Direction.  # noqa: E501

        :param orientation_direction: The orientation_direction of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if orientation_direction is not None:
            allowed_values = ["Horizontal", "Vertical"]  # noqa: E501
            if orientation_direction.isdigit():
                int_orientation_direction = int(orientation_direction)
                if int_orientation_direction < 0 or int_orientation_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `orientation_direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(orientation_direction, allowed_values)
                    )
                self._orientation_direction = allowed_values[int_orientation_direction]
                return
            if orientation_direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `orientation_direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(orientation_direction, allowed_values)
                )
        self._orientation_direction = orientation_direction

    @property
    def through_black(self):
        """Gets the through_black of this SlideShowTransition.  # noqa: E501

        Through Black.  # noqa: E501

        :return: The through_black of this SlideShowTransition.  # noqa: E501
        :rtype: bool
        """
        return self._through_black

    @through_black.setter
    def through_black(self, through_black):
        """Sets the through_black of this SlideShowTransition.

        Through Black.  # noqa: E501

        :param through_black: The through_black of this SlideShowTransition.  # noqa: E501
        :type: bool
        """
        self._through_black = through_black

    @property
    def corner_and_center_direction(self):
        """Gets the corner_and_center_direction of this SlideShowTransition.  # noqa: E501

        Orientation.  # noqa: E501

        :return: The corner_and_center_direction of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._corner_and_center_direction

    @corner_and_center_direction.setter
    def corner_and_center_direction(self, corner_and_center_direction):
        """Sets the corner_and_center_direction of this SlideShowTransition.

        Orientation.  # noqa: E501

        :param corner_and_center_direction: The corner_and_center_direction of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if corner_and_center_direction is not None:
            allowed_values = ["LeftDown", "LeftUp", "RightDown", "RightUp", "Center"]  # noqa: E501
            if corner_and_center_direction.isdigit():
                int_corner_and_center_direction = int(corner_and_center_direction)
                if int_corner_and_center_direction < 0 or int_corner_and_center_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `corner_and_center_direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(corner_and_center_direction, allowed_values)
                    )
                self._corner_and_center_direction = allowed_values[int_corner_and_center_direction]
                return
            if corner_and_center_direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `corner_and_center_direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(corner_and_center_direction, allowed_values)
                )
        self._corner_and_center_direction = corner_and_center_direction

    @property
    def shred_pattern(self):
        """Gets the shred_pattern of this SlideShowTransition.  # noqa: E501

        Shred Pattern.  # noqa: E501

        :return: The shred_pattern of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._shred_pattern

    @shred_pattern.setter
    def shred_pattern(self, shred_pattern):
        """Sets the shred_pattern of this SlideShowTransition.

        Shred Pattern.  # noqa: E501

        :param shred_pattern: The shred_pattern of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if shred_pattern is not None:
            allowed_values = ["Strip", "Rectangle"]  # noqa: E501
            if shred_pattern.isdigit():
                int_shred_pattern = int(shred_pattern)
                if int_shred_pattern < 0 or int_shred_pattern >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `shred_pattern` ({0}), must be one of {1}"  # noqa: E501
                        .format(shred_pattern, allowed_values)
                    )
                self._shred_pattern = allowed_values[int_shred_pattern]
                return
            if shred_pattern not in allowed_values:
                raise ValueError(
                    "Invalid value for `shred_pattern` ({0}), must be one of {1}"  # noqa: E501
                    .format(shred_pattern, allowed_values)
                )
        self._shred_pattern = shred_pattern

    @property
    def orientation(self):
        """Gets the orientation of this SlideShowTransition.  # noqa: E501

        Orientation.  # noqa: E501

        :return: The orientation of this SlideShowTransition.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this SlideShowTransition.

        Orientation.  # noqa: E501

        :param orientation: The orientation of this SlideShowTransition.  # noqa: E501
        :type: str
        """
        if orientation is not None:
            allowed_values = ["Horizontal", "Vertical"]  # noqa: E501
            if orientation.isdigit():
                int_orientation = int(orientation)
                if int_orientation < 0 or int_orientation >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                        .format(orientation, allowed_values)
                    )
                self._orientation = allowed_values[int_orientation]
                return
            if orientation not in allowed_values:
                raise ValueError(
                    "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                    .format(orientation, allowed_values)
                )
        self._orientation = orientation

    @property
    def spokes(self):
        """Gets the spokes of this SlideShowTransition.  # noqa: E501

        Spokes.  # noqa: E501

        :return: The spokes of this SlideShowTransition.  # noqa: E501
        :rtype: int
        """
        return self._spokes

    @spokes.setter
    def spokes(self, spokes):
        """Sets the spokes of this SlideShowTransition.

        Spokes.  # noqa: E501

        :param spokes: The spokes of this SlideShowTransition.  # noqa: E501
        :type: int
        """
        self._spokes = spokes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlideShowTransition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class Operation(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'method': 'str',
        'status': 'str',
        'progress': 'OperationProgress',
        'created': 'datetime',
        'started': 'datetime',
        'failed': 'datetime',
        'canceled': 'datetime',
        'finished': 'datetime',
        'error': 'OperationError'
    }

    attribute_map = {
        'id': 'id',
        'method': 'method',
        'status': 'status',
        'progress': 'progress',
        'created': 'created',
        'started': 'started',
        'failed': 'failed',
        'canceled': 'canceled',
        'finished': 'finished',
        'error': 'error'
    }

    type_determiners = {
    }

    def __init__(self, id=None, method=None, status=None, progress=None, created=None, started=None, failed=None, canceled=None, finished=None, error=None):  # noqa: E501
        """Operation - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._method = None
        self._status = None
        self._progress = None
        self._created = None
        self._started = None
        self._failed = None
        self._canceled = None
        self._finished = None
        self._error = None

        self.id = id
        self.method = method
        self.status = status
        if progress is not None:
            self.progress = progress
        if created is not None:
            self.created = created
        if started is not None:
            self.started = started
        if failed is not None:
            self.failed = failed
        if canceled is not None:
            self.canceled = canceled
        if finished is not None:
            self.finished = finished
        if error is not None:
            self.error = error

    @property
    def id(self):
        """Gets the id of this Operation.  # noqa: E501


        :return: The id of this Operation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Operation.


        :param id: The id of this Operation.  # noqa: E501
        :type: str
        """
        self._id = id

    @property
    def method(self):
        """Gets the method of this Operation.  # noqa: E501


        :return: The method of this Operation.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this Operation.


        :param method: The method of this Operation.  # noqa: E501
        :type: str
        """
        if method is not None:
            allowed_values = ["Convert", "DownloadPresentation", "ConvertAndSave", "SavePresentation", "Merge", "MergeAndSave", "Split", "UploadAndSplit"]  # noqa: E501
            if method.isdigit():
                int_method = int(method)
                if int_method < 0 or int_method >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                        .format(method, allowed_values)
                    )
                self._method = allowed_values[int_method]
                return
            if method not in allowed_values:
                raise ValueError(
                    "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                    .format(method, allowed_values)
                )
        self._method = method

    @property
    def status(self):
        """Gets the status of this Operation.  # noqa: E501


        :return: The status of this Operation.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Operation.


        :param status: The status of this Operation.  # noqa: E501
        :type: str
        """
        if status is not None:
            allowed_values = ["Created", "Enqueued", "Started", "Failed", "Canceled", "Finished"]  # noqa: E501
            if status.isdigit():
                int_status = int(status)
                if int_status < 0 or int_status >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                        .format(status, allowed_values)
                    )
                self._status = allowed_values[int_status]
                return
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                    .format(status, allowed_values)
                )
        self._status = status

    @property
    def progress(self):
        """Gets the progress of this Operation.  # noqa: E501


        :return: The progress of this Operation.  # noqa: E501
        :rtype: OperationProgress
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this Operation.


        :param progress: The progress of this Operation.  # noqa: E501
        :type: OperationProgress
        """
        self._progress = progress

    @property
    def created(self):
        """Gets the created of this Operation.  # noqa: E501


        :return: The created of this Operation.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Operation.


        :param created: The created of this Operation.  # noqa: E501
        :type: datetime
        """
        self._created = created

    @property
    def started(self):
        """Gets the started of this Operation.  # noqa: E501


        :return: The started of this Operation.  # noqa: E501
        :rtype: datetime
        """
        return self._started

    @started.setter
    def started(self, started):
        """Sets the started of this Operation.


        :param started: The started of this Operation.  # noqa: E501
        :type: datetime
        """
        self._started = started

    @property
    def failed(self):
        """Gets the failed of this Operation.  # noqa: E501


        :return: The failed of this Operation.  # noqa: E501
        :rtype: datetime
        """
        return self._failed

    @failed.setter
    def failed(self, failed):
        """Sets the failed of this Operation.


        :param failed: The failed of this Operation.  # noqa: E501
        :type: datetime
        """
        self._failed = failed

    @property
    def canceled(self):
        """Gets the canceled of this Operation.  # noqa: E501


        :return: The canceled of this Operation.  # noqa: E501
        :rtype: datetime
        """
        return self._canceled

    @canceled.setter
    def canceled(self, canceled):
        """Sets the canceled of this Operation.


        :param canceled: The canceled of this Operation.  # noqa: E501
        :type: datetime
        """
        self._canceled = canceled

    @property
    def finished(self):
        """Gets the finished of this Operation.  # noqa: E501


        :return: The finished of this Operation.  # noqa: E501
        :rtype: datetime
        """
        return self._finished

    @finished.setter
    def finished(self, finished):
        """Sets the finished of this Operation.


        :param finished: The finished of this Operation.  # noqa: E501
        :type: datetime
        """
        self._finished = finished

    @property
    def error(self):
        """Gets the error of this Operation.  # noqa: E501


        :return: The error of this Operation.  # noqa: E501
        :rtype: OperationError
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this Operation.


        :param error: The error of this Operation.  # noqa: E501
        :type: OperationError
        """
        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Operation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class MarkdownExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'default_regular_font': 'str',
        'gradient_style': 'str',
        'font_fallback_rules': 'list[FontFallbackRule]',
        'font_subst_rules': 'list[FontSubstRule]',
        'format': 'str',
        'export_type': 'str',
        'flavor': 'str',
        'new_line_type': 'str',
        'images_save_folder_name': 'str',
        'show_slide_number': 'bool',
        'show_comments': 'bool',
        'show_hidden_slides': 'bool'
    }

    attribute_map = {
        'default_regular_font': 'defaultRegularFont',
        'gradient_style': 'gradientStyle',
        'font_fallback_rules': 'fontFallbackRules',
        'font_subst_rules': 'fontSubstRules',
        'format': 'format',
        'export_type': 'exportType',
        'flavor': 'flavor',
        'new_line_type': 'newLineType',
        'images_save_folder_name': 'imagesSaveFolderName',
        'show_slide_number': 'showSlideNumber',
        'show_comments': 'showComments',
        'show_hidden_slides': 'showHiddenSlides'
    }

    type_determiners = {
        'format': 'md',
    }

    def __init__(self, default_regular_font=None, gradient_style=None, font_fallback_rules=None, font_subst_rules=None, format='md', export_type=None, flavor=None, new_line_type=None, images_save_folder_name=None, show_slide_number=None, show_comments=None, show_hidden_slides=None):  # noqa: E501
        """MarkdownExportOptions - a model defined in Swagger"""  # noqa: E501
        super(MarkdownExportOptions, self).__init__(default_regular_font, gradient_style, font_fallback_rules, font_subst_rules, format)

        self._export_type = None
        self._flavor = None
        self._new_line_type = None
        self._images_save_folder_name = None
        self._show_slide_number = None
        self._show_comments = None
        self._show_hidden_slides = None
        self.format = 'md'

        if export_type is not None:
            self.export_type = export_type
        if flavor is not None:
            self.flavor = flavor
        if new_line_type is not None:
            self.new_line_type = new_line_type
        if images_save_folder_name is not None:
            self.images_save_folder_name = images_save_folder_name
        if show_slide_number is not None:
            self.show_slide_number = show_slide_number
        if show_comments is not None:
            self.show_comments = show_comments
        if show_hidden_slides is not None:
            self.show_hidden_slides = show_hidden_slides

    @property
    def export_type(self):
        """Gets the export_type of this MarkdownExportOptions.  # noqa: E501

        Specifies markdown specification to convert presentation. Default is TextOnly.  # noqa: E501

        :return: The export_type of this MarkdownExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._export_type

    @export_type.setter
    def export_type(self, export_type):
        """Sets the export_type of this MarkdownExportOptions.

        Specifies markdown specification to convert presentation. Default is TextOnly.  # noqa: E501

        :param export_type: The export_type of this MarkdownExportOptions.  # noqa: E501
        :type: str
        """
        if export_type is not None:
            allowed_values = ["Sequential", "TextOnly", "Visual"]  # noqa: E501
            if export_type.isdigit():
                int_export_type = int(export_type)
                if int_export_type < 0 or int_export_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `export_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(export_type, allowed_values)
                    )
                self._export_type = allowed_values[int_export_type]
                return
            if export_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `export_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(export_type, allowed_values)
                )
        self._export_type = export_type

    @property
    def flavor(self):
        """Gets the flavor of this MarkdownExportOptions.  # noqa: E501

        Specifies markdown specification to convert presentation. Default is MultiMarkdown.  # noqa: E501

        :return: The flavor of this MarkdownExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._flavor

    @flavor.setter
    def flavor(self, flavor):
        """Sets the flavor of this MarkdownExportOptions.

        Specifies markdown specification to convert presentation. Default is MultiMarkdown.  # noqa: E501

        :param flavor: The flavor of this MarkdownExportOptions.  # noqa: E501
        :type: str
        """
        if flavor is not None:
            allowed_values = ["Github", "Gruber", "MultiMarkdown", "CommonMark", "MarkdownExtra", "Pandoc", "Kramdown", "Markua", "Maruku", "Markdown2", "Remarkable", "Showdown", "Ghost", "GitLab", "Haroopad", "IaWriter", "Redcarpet", "ScholarlyMarkdown", "Taiga", "Trello", "S9ETextFormatter", "XWiki", "StackOverflow", "Default"]  # noqa: E501
            if flavor.isdigit():
                int_flavor = int(flavor)
                if int_flavor < 0 or int_flavor >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `flavor` ({0}), must be one of {1}"  # noqa: E501
                        .format(flavor, allowed_values)
                    )
                self._flavor = allowed_values[int_flavor]
                return
            if flavor not in allowed_values:
                raise ValueError(
                    "Invalid value for `flavor` ({0}), must be one of {1}"  # noqa: E501
                    .format(flavor, allowed_values)
                )
        self._flavor = flavor

    @property
    def new_line_type(self):
        """Gets the new_line_type of this MarkdownExportOptions.  # noqa: E501

        Specifies whether the generated document should have new lines of \\\\r(Macintosh), \\\\n(Unix) or \\\\r\\\\n(Windows). Default is Unix.  # noqa: E501

        :return: The new_line_type of this MarkdownExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._new_line_type

    @new_line_type.setter
    def new_line_type(self, new_line_type):
        """Sets the new_line_type of this MarkdownExportOptions.

        Specifies whether the generated document should have new lines of \\\\r(Macintosh), \\\\n(Unix) or \\\\r\\\\n(Windows). Default is Unix.  # noqa: E501

        :param new_line_type: The new_line_type of this MarkdownExportOptions.  # noqa: E501
        :type: str
        """
        if new_line_type is not None:
            allowed_values = ["Windows", "Unix", "Mac"]  # noqa: E501
            if new_line_type.isdigit():
                int_new_line_type = int(new_line_type)
                if int_new_line_type < 0 or int_new_line_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `new_line_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(new_line_type, allowed_values)
                    )
                self._new_line_type = allowed_values[int_new_line_type]
                return
            if new_line_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `new_line_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(new_line_type, allowed_values)
                )
        self._new_line_type = new_line_type

    @property
    def images_save_folder_name(self):
        """Gets the images_save_folder_name of this MarkdownExportOptions.  # noqa: E501

        Specifies folder name to save images. Default is Images.   # noqa: E501

        :return: The images_save_folder_name of this MarkdownExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._images_save_folder_name

    @images_save_folder_name.setter
    def images_save_folder_name(self, images_save_folder_name):
        """Sets the images_save_folder_name of this MarkdownExportOptions.

        Specifies folder name to save images. Default is Images.   # noqa: E501

        :param images_save_folder_name: The images_save_folder_name of this MarkdownExportOptions.  # noqa: E501
        :type: str
        """
        self._images_save_folder_name = images_save_folder_name

    @property
    def show_slide_number(self):
        """Gets the show_slide_number of this MarkdownExportOptions.  # noqa: E501

        Specifies whether the generated document should include slide number. Default is false.   # noqa: E501

        :return: The show_slide_number of this MarkdownExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_slide_number

    @show_slide_number.setter
    def show_slide_number(self, show_slide_number):
        """Sets the show_slide_number of this MarkdownExportOptions.

        Specifies whether the generated document should include slide number. Default is false.   # noqa: E501

        :param show_slide_number: The show_slide_number of this MarkdownExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_slide_number = show_slide_number

    @property
    def show_comments(self):
        """Gets the show_comments of this MarkdownExportOptions.  # noqa: E501

        Specifies whether the generated document should include comments. Default is false.   # noqa: E501

        :return: The show_comments of this MarkdownExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_comments

    @show_comments.setter
    def show_comments(self, show_comments):
        """Sets the show_comments of this MarkdownExportOptions.

        Specifies whether the generated document should include comments. Default is false.   # noqa: E501

        :param show_comments: The show_comments of this MarkdownExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_comments = show_comments

    @property
    def show_hidden_slides(self):
        """Gets the show_hidden_slides of this MarkdownExportOptions.  # noqa: E501

        Specifies whether the generated document should include hidden slides. Default is false.   # noqa: E501

        :return: The show_hidden_slides of this MarkdownExportOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_hidden_slides

    @show_hidden_slides.setter
    def show_hidden_slides(self, show_hidden_slides):
        """Sets the show_hidden_slides of this MarkdownExportOptions.

        Specifies whether the generated document should include hidden slides. Default is false.   # noqa: E501

        :param show_hidden_slides: The show_hidden_slides of this MarkdownExportOptions.  # noqa: E501
        :type: bool
        """
        self._show_hidden_slides = show_hidden_slides

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarkdownExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
